==> clapack-3.1.1.tgz: CLAPACK-3.1.1/TESTING/EIG/dlasum.c <==
#include "blaswrap.h"
/* dlasum.f -- translated by f2c (version 20061008).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "f2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* Subroutine */ int dlasum_(char *type__, integer *iounit, integer *ie, 
	integer *nrun)
{
    /* Format strings */
    static char fmt_9999[] = "(1x,a3,a2,i4,a8,i5,a35)";
    static char fmt_9998[] = "(/1x,a14,a3,a23,i5,a11)";

    /* Builtin functions */
    integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);

    /* Fortran I/O blocks */
    static cilist io___1 = { 0, 0, 0, fmt_9999, 0 };
    static cilist io___2 = { 0, 0, 0, fmt_9998, 0 };



/*  -- LAPACK auxiliary test routine (version 3.1) --   
       Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..   
       November 2006   


    Purpose   
    =======   

    DLASUM prints a summary of the results from one of the test routines.   

    ===================================================================== */


    if (*ie > 0) {
	io___1.ciunit = *iounit;
	s_wsfe(&io___1);
	do_fio(&c__1, type__, (ftnlen)3);
	do_fio(&c__1, ": ", (ftnlen)2);
	do_fio(&c__1, (char *)&(*ie), (ftnlen)sizeof(integer));
	do_fio(&c__1, " out of ", (ftnlen)8);
	do_fio(&c__1, (char *)&(*nrun), (ftnlen)sizeof(integer));
	do_fio(&c__1, " tests failed to pass the threshold", (ftnlen)35);
	e_wsfe();
    } else {
	io___2.ciunit = *iounit;
	s_wsfe(&io___2);
	do_fio(&c__1, "All tests for ", (ftnlen)14);
	do_fio(&c__1, type__, (ftnlen)3);
	do_fio(&c__1, " passed the threshold (", (ftnlen)23);
	do_fio(&c__1, (char *)&(*nrun), (ftnlen)sizeof(integer));
	do_fio(&c__1, " tests run)", (ftnlen)11);
	e_wsfe();
    }
    return 0;

/*     End of DLASUM */

} /* dlasum_ */

==> clapack-3.1.1.1.tgz: CLAPACK-3.1.1.1/TESTING/EIG/dlasum.c <==
#include "f2c.h"
#include "blaswrap.h"

/* Table of constant values */

static integer c__1 = 1;

/* Subroutine */ int dlasum_(char *type__, integer *iounit, integer *ie, 
	integer *nrun)
{
    /* Format strings */
    static char fmt_9999[] = "(1x,a3,a2,i4,a8,i5,a35)";
    static char fmt_9998[] = "(/1x,a14,a3,a23,i5,a11)";

    /* Builtin functions */
    integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);

    /* Fortran I/O blocks */
    static cilist io___1 = { 0, 0, 0, fmt_9999, 0 };
    static cilist io___2 = { 0, 0, 0, fmt_9998, 0 };



/*  -- LAPACK auxiliary test routine (version 3.1) -- */
/*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
/*     November 2006 */

/*     .. Scalar Arguments .. */
/*     .. */

/*  Purpose */
/*  ======= */

/*  DLASUM prints a summary of the results from one of the test routines. */

/*  ===================================================================== */

/*     .. Executable Statements .. */

    if (*ie > 0) {
	io___1.ciunit = *iounit;
	s_wsfe(&io___1);
	do_fio(&c__1, type__, (ftnlen)3);
	do_fio(&c__1, ": ", (ftnlen)2);
	do_fio(&c__1, (char *)&(*ie), (ftnlen)sizeof(integer));
	do_fio(&c__1, " out of ", (ftnlen)8);
	do_fio(&c__1, (char *)&(*nrun), (ftnlen)sizeof(integer));
	do_fio(&c__1, " tests failed to pass the threshold", (ftnlen)35);
	e_wsfe();
    } else {
	io___2.ciunit = *iounit;
	s_wsfe(&io___2);
	do_fio(&c__1, "All tests for ", (ftnlen)14);
	do_fio(&c__1, type__, (ftnlen)3);
	do_fio(&c__1, " passed the threshold (", (ftnlen)23);
	do_fio(&c__1, (char *)&(*nrun), (ftnlen)sizeof(integer));
	do_fio(&c__1, " tests run)", (ftnlen)11);
	e_wsfe();
    }
    return 0;

/*     End of DLASUM */

} /* dlasum_ */
